from django.conf import settings
from django.http import HttpResponse
from django.shortcuts import render
from django.views.decorators.csrf import csrf_exempt
from django.core.exceptions import ImproperlyConfigured
from django.core.urlresolvers import reverse
from django.contrib.admin.views.decorators import staff_member_required

from cked import elFinder
from cked.widgets import json_encode
from cked import default_settings

try:
    import json
except ImportError:
    from django.utils import simplejson as json


json_encode = json.JSONEncoder().encode


@staff_member_required
def elfinder(request):
    options = default_settings.ELFINDER_DEFAULT_OPTIONS.copy()
    options['url'] = reverse('cked_elfinder_connector')

    user_options = getattr(settings, 'ELFINDER_OPTIONS', None)

    if user_options is not None:
        if isinstance(user_options, dict):
            # Override defaults with CKEDITOR_OPTIONS.
            options.update(user_options)
        else:
            raise ImproperlyConfigured('CKEDITOR_OPTIONS setting must be a '
                                       'dictionary type.')

    return render(request, 'cked/elfinder.html', {
        'options': json_encode(options),
    })


@staff_member_required
@csrf_exempt
def elfinder_connector(request):
    elf = elFinder.connector(settings.ELFINDER_OPTIONS)
    req = {}

    if request.method == 'GET':
        form = request.GET
    else:
        form = request.POST

    for field in elf.httpAllowedParameters:
        if field in form:
            req[field] = form.get(field)

            # Hack by Kidwind
            if field == 'targets[]' and hasattr(form, 'getlist'):
                req[field] = form.getlist(field)

    if request.FILES and request.FILES.getlist('upload[]'):
        up_files = {}
        for up in request.FILES.getlist('upload[]'):
            if up.name:
                up_files[up.name] = up.file

        req[field] = up_files

    status, header, response = elf.run(req)

    if not response is None and status == 200:
        if 'file' in response and isinstance(response['file'], file):
            response['file'].close()

    return HttpResponse(json.dumps(response), content_type='application/json')



from appconf import AppConf
from django.conf import settings
import os


class CKEDConf(AppConf):
    STATIC_URL = u'/static/'
    MEDIA_URL = u'/media/'
    MEDIA_ROOT = u'media'
    ELFINDER_OPTIONS = {
        'root': os.path.join(os.getcwd(), 'media', 'uploads'),
        'URL': '/media/uploads/',
    }

    def configure_static_url(self, value):
        if not getattr(settings, 'STATIC_URL', None):
            self._meta.holder.STATIC_URL = value
            return value
        return getattr(settings, 'STATIC_URL')

    def configure_media_url(self, value):
        if not getattr(settings, 'MEDIA_URL', None):
            self._meta.holder.MEDIA_URL = value
            return value
        return getattr(settings, 'MEDIA_URL')

    def configure_media_root(self, value):
        if not getattr(settings, 'MEDIA_ROOT', None):
            self._meta.holder.MEDIA_ROOT = value
            return value
        return getattr(settings, 'MEDIA_ROOT')

    def configure_elfinder_options(self, value):
        if not os.path.exists(os.path.join(os.getcwd(), 'media', 'uploads')):
            os.makedirs(os.path.join(os.getcwd(), 'media', 'uploads'))
        if not getattr(settings, 'ELFINDER_OPTIONS', None):
            self._meta.holder.ELFINDER_OPTIONS = value
            return value
        return getattr(settings, 'ELFINDER_OPTIONS')


import os
import cked
from setuptools import setup, find_packages


# Utility function to read the README file.
def read(fname):
    return open(os.path.join(os.path.dirname(__file__), fname)).read()

setup(
    name='twentytab-cked',
    version=cked.__version__,
    author='20tab srl',
    author_email='info@20tab.com',
    description=('CKEditor and elFinder integration for Django Framework.'),
    license='BSD',
    keywords='django, ckeditor, elfinder, wysiwyg, upload',
    url='https://github.com/20tab/twentytab-cked',
    long_description=read('README.rst'),
    install_requires=[
        'Django >=1.6',
        'django-appconf>=0.6',
    ],
    packages=find_packages(),
    include_package_data=True,
    package_data={
        '': ['*.html', '*.css', '*.js', '*.gif', '*.png', ],
    }
)
